﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using System.Threading;
using System.Windows;
using System.Xml.Serialization;
using System.Globalization;
using System.Data;

namespace WpfMultiCombo
{
    public class Plants : ObservableCollection<Plant>
    {
        public Plants()
            : base()
        {
        }

        public Plants(IEnumerable<Plant> list)
            : base(list)
        {
        }

        public Plants(List<Plant> list)
            : base(list)
        {
        }



        public Plants(DataTable table)
            : base(table.AsEnumerable().Select(row => new Plant
            {
                PlantNo = row.Field<Int32>("PlantNo"),
                PlantName = row.Field<string>("PlantName"),
                LocalizationCode = row.Field<string>("LocalizationCode"),

                AddressNo = row.Field<Int32?>("AddressNo"),

                ClientSourceNo = row.Field<Int32>("ClientSourceNo"),
                RecipientOfGoodsSourceNo = row.Field<Int32>("RecipientOfGoodsSourceNo"),
                ArticleSourceNo = row.Field<Int32>("ArticleSourceNo"),
                PackagingSourceNo = row.Field<Int32>("PackagingSourceNo"),

                ArticleCompanyOrgNo = row.Field<Int16?>("ArticleCompanyOrgNo"),
                AddressCompanyOrgNo = row.Field<Int16?>("AddressCompanyOrgNo"),

                NoInSourcesystem = row.Field<string>("NoInSourcesystem"),
                BehNo = row.Field<Int32?>("BehNo"),
                MappingFlag = row.Field<Int16?>("MappingFlag"),
                IsFobis = row.Field<bool>("IsFobis"),
                IsOrgBySeller = row.Field<bool>("IsOrgBySeller"),
                DivisionNo = row.Field<Int32?>("DivisionNo"),
                ActiveFlag = row.Field<bool>("ActiveFlag"),
                InsDate = row.Field<DateTime>("InsDate"),
                InsUser = row.Field<string>("InsUser"),
                UpdDate = row.Field<DateTime>("UpdDate"),
                UpdUser = row.Field<string>("UpdUser"),

                Name1 = row.Field<string>("Name1"),
                Name2 = row.Field<string>("Name2"),
                Street = row.Field<string>("Street"),
                HouseNo = row.Field<string>("HouseNo"),
                CountryCode = row.Field<string>("CountryCode"),
                ZipCode = row.Field<string>("ZipCode"),
                City = row.Field<string>("City"),
                PhoneNo1 = row.Field<string>("PhoneNo1"),
                PhoneNo2 = row.Field<string>("PhoneNo2"),
                FaxNo = row.Field<string>("FaxNo"),
                ESNo = row.Field<string>("ESNo"),
                EZNo = row.Field<string>("EZNo"),
                UIN = row.Field<string>("UIN"),
                LanguageCode = row.Field<string>("LanguageCode")

            })) { }

        public Plant GetPlant(int plantno)
        {
            return (from o in this.Items
                    where o.PlantNo == plantno
                    select o).SingleOrDefault();
        }

    }

    public class Plant : Address
    {
        public Int32 PlantNo { get; set; }
        public string PlantName { get; set; }
        public string LocalizationCode { get; set; }

        public Int32? AddressNo { get; set; }

        public Int32 ClientSourceNo { get; set; }
        public Int32 RecipientOfGoodsSourceNo { get; set; }
        public Int32 ArticleSourceNo { get; set; }
        public Int32 PackagingSourceNo { get; set; }

        public Int16? ArticleCompanyOrgNo { get; set; }
        public Int16? AddressCompanyOrgNo { get; set; }

        public string NoInSourcesystem { get; set; }

        public Int32? BehNo { get; set; }
        public Int16? MappingFlag { get; set; }
        public bool IsFobis { get; set; }
        public bool IsOrgBySeller { get; set; }
        public Int32? DivisionNo { get; set; }
        public bool ActiveFlag { get; set; }

        public DateTime InsDate { get; set; }
        public string InsUser { get; set; }
        public DateTime? UpdDate { get; set; }
        public string UpdUser { get; set; }

        public string StrPlantNo
        {
            get
            {
                if (PlantNo == 0)
                {
                    return string.Empty;
                }
                return PlantNo.ToString();
            }
        }
    }
}
